@@ -4,7 +4,7 @@ import numpy as np
 import scipy.special as sc
 
 
-class elementary:
+class Elementary:
     """A class for elementary homogeneous symmetric polynomials."""
 
     def compute(self, x, n):
@@ -23,7 +23,7 @@ class elementary:
         result = np.array([1])
         y = x.copy()
 
-        for i in range(1, n+1):
+        for i in range(n):
             result = np.append(result, sum(y))
             for j in range(len(y)):
                 y[j] = 0
@@ -50,7 +50,7 @@ class elementary:
         return result
 
 
-class complete:
+class Complete:
     """A class for complete homogeneous symmetric polynomials."""
 
     def compute(self, x, n):
@@ -69,7 +69,7 @@ class complete:
         result = np.array([1])
         y = x.copy()
 
-        for i in range(1, n + 1):
+        for i in range(n):
             result = np.append(result, sum(y))
             for j in range(len(y)):
                 my_sum = 0
@@ -97,7 +97,7 @@ class complete:
         return result
 
 
-class power_sum:
+class Power_Sum:
     """A class for power sum polynomials."""
 
     def compute(self, x, n):
@@ -116,7 +116,7 @@ class power_sum:
         result = np.array([1])
         y = x.copy()
 
-        for i in range(1, n + 1):
+        for i in range(n):
             result = np.append(result, sum(y))
             my_sum = 0
             for j in range(len(y)):
@@ -139,5 +139,5 @@ class power_sum:
         """
         result = self.compute(x, n)
         for i in range(1, len(result)):
-            result[i] /= (len(x) - 1)
+            result[i] /= (len(x))
         return result
